#!/bin/bash
#
# Prints path, num of files and dimension of a folder
# if the num of files is greater than a certain threshold
#
# Usage
# $ bash <script_name> <target_dir> <threshold>
#
# Example of usage:
# $ bash numfiles.sh mydir 1000
#
# Author: Cristiano Urban
# Email: cristiano.urban@inaf.it
#



# Exit on errors
set -e

DIRS_LIST=$(du "$1" | awk '{$1=""; print substr($0,2)}')
TMP_OUTPUT="tmp_crowded_dirs.txt"
OUTPUT="crowded_dirs.txt"

touch $TMP_OUTPUT
touch $OUTPUT

echo "$DIRS_LIST" | while read i
  do
    NUM_FILES=$(find "$i" -maxdepth 1 -type f | wc -l)
    if [ "$NUM_FILES" -gt "$2" ]; then
        DISK_USAGE=$(du -S -h -d 0 "$i" | awk '{print $1}')
        echo -ne "$i\x20" >> "$TMP_OUTPUT"
        echo -ne "$NUM_FILES\x20" >> "$TMP_OUTPUT"
        echo "$DISK_USAGE" >> "$TMP_OUTPUT"
    fi
  done

# Creates a better view...
cat "$TMP_OUTPUT" | column -t > "$OUTPUT" && rm -f "$TMP_OUTPUT"
